Class: Aws::EBS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::EBS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ebs/client.rb,
sig/client.rbs
Overview
An API client for EBS. To construct a client, you need to configure a :region and :credentials.
client = Aws::EBS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CompleteSnapshotResponseSuccess, _GetSnapshotBlockResponseSuccess, _ListChangedBlocksResponseSuccess, _ListSnapshotBlocksResponseSuccess, _PutSnapshotBlockResponseSuccess, _StartSnapshotResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#complete_snapshot(params = {}) ⇒ Types::CompleteSnapshotResponse
Seals and completes the snapshot after all of the required blocks of data have been written to it.
-
#get_snapshot_block(params = {}) ⇒ Types::GetSnapshotBlockResponse
Returns the data in a block in an Amazon Elastic Block Store snapshot.
-
#list_changed_blocks(params = {}) ⇒ Types::ListChangedBlocksResponse
Returns information about the blocks that are different between two Amazon Elastic Block Store snapshots of the same volume/snapshot lineage.
-
#list_snapshot_blocks(params = {}) ⇒ Types::ListSnapshotBlocksResponse
Returns information about the blocks in an Amazon Elastic Block Store snapshot.
-
#put_snapshot_block(params = {}) ⇒ Types::PutSnapshotBlockResponse
Writes a block of data to a snapshot.
-
#start_snapshot(params = {}) ⇒ Types::StartSnapshotResponse
Creates a new Amazon EBS snapshot.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ebs/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1101 1102 1103 |
# File 'lib/aws-sdk-ebs/client.rb', line 1101 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1104 1105 1106 |
# File 'lib/aws-sdk-ebs/client.rb', line 1104 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/aws-sdk-ebs/client.rb', line 1074 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::EBS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ebs' context[:gem_version] = '1.76.0' Seahorse::Client::Request.new(handlers, context) end |
#complete_snapshot(params = {}) ⇒ Types::CompleteSnapshotResponse
Seals and completes the snapshot after all of the required blocks of
data have been written to it. Completing the snapshot changes the
status to completed. You cannot write new blocks to a snapshot after
it has been completed.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
86 |
# File 'sig/client.rbs', line 86
def complete_snapshot: (
|
#get_snapshot_block(params = {}) ⇒ Types::GetSnapshotBlockResponse
Returns the data in a block in an Amazon Elastic Block Store snapshot.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
103 |
# File 'sig/client.rbs', line 103
def get_snapshot_block: (
|
#list_changed_blocks(params = {}) ⇒ Types::ListChangedBlocksResponse
Returns information about the blocks that are different between two Amazon Elastic Block Store snapshots of the same volume/snapshot lineage.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
119 |
# File 'sig/client.rbs', line 119
def list_changed_blocks: (
|
#list_snapshot_blocks(params = {}) ⇒ Types::ListSnapshotBlocksResponse
Returns information about the blocks in an Amazon Elastic Block Store snapshot.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
137 |
# File 'sig/client.rbs', line 137
def list_snapshot_blocks: (
|
#put_snapshot_block(params = {}) ⇒ Types::PutSnapshotBlockResponse
Writes a block of data to a snapshot. If the specified block contains
data, the existing data is overwritten. The target snapshot must be in
the pending state.
Data written to a snapshot must be aligned with 512-KiB sectors.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
151 |
# File 'sig/client.rbs', line 151
def put_snapshot_block: (
|
#start_snapshot(params = {}) ⇒ Types::StartSnapshotResponse
Creates a new Amazon EBS snapshot. The new snapshot enters the
pending state after the request completes.
After creating the snapshot, use PutSnapshotBlock to write blocks of data to the snapshot.
5xx) error
responses, and ThrottlingException and RequestThrottledException
client error responses. For more information see Error retries in
the Amazon Elastic Compute Cloud User Guide.
177 |
# File 'sig/client.rbs', line 177
def start_snapshot: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1094 1095 1096 |
# File 'lib/aws-sdk-ebs/client.rb', line 1094 def waiter_names [] end |