Class: Aws::EBS::Types::ChangedBlock

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ebs/types.rb

Overview

A block of data in an Amazon Elastic Block Store snapshot that is different from another snapshot of the same volume/snapshot lineage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_index ⇒ Integer

The block index.

Returns:

  • (Integer)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-ebs/types.rb', line 71

class ChangedBlock < Struct.new(
  :block_index,
  :first_block_token,
  :second_block_token)
  SENSITIVE = []
  include Aws::Structure
end

#first_block_token ⇒ String

The block token for the block index of the FirstSnapshotId specified in the ListChangedBlocks operation. This value is absent if the first snapshot does not have the changed block that is on the second snapshot.

Returns:

  • (String)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-ebs/types.rb', line 71

class ChangedBlock < Struct.new(
  :block_index,
  :first_block_token,
  :second_block_token)
  SENSITIVE = []
  include Aws::Structure
end

#second_block_token ⇒ String

The block token for the block index of the SecondSnapshotId specified in the ListChangedBlocks operation.

Returns:

  • (String)


71
72
73
74
75
76
77
# File 'lib/aws-sdk-ebs/types.rb', line 71

class ChangedBlock < Struct.new(
  :block_index,
  :first_block_token,
  :second_block_token)
  SENSITIVE = []
  include Aws::Structure
end