Class: Aws::EBS::Types::CompleteSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ebs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#changed_blocks_count ⇒ Integer

The number of blocks that were written to the snapshot.

Returns:

  • (Integer)


110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-ebs/types.rb', line 110

class CompleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :changed_blocks_count,
  :checksum,
  :checksum_algorithm,
  :checksum_aggregation_method)
  SENSITIVE = []
  include Aws::Structure
end

#checksum ⇒ String

An aggregated Base-64 SHA256 checksum based on the checksums of each written block.

To generate the aggregated checksum using the linear aggregation method, arrange the checksums for each written block in ascending order of their block index, concatenate them to form a single string, and then generate the checksum on the entire string using the SHA256 algorithm.

Returns:

  • (String)


110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-ebs/types.rb', line 110

class CompleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :changed_blocks_count,
  :checksum,
  :checksum_algorithm,
  :checksum_aggregation_method)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_aggregation_method ⇒ String

The aggregation method used to generate the checksum. Currently, the only supported aggregation method is LINEAR.

Returns:

  • (String)


110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-ebs/types.rb', line 110

class CompleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :changed_blocks_count,
  :checksum,
  :checksum_algorithm,
  :checksum_aggregation_method)
  SENSITIVE = []
  include Aws::Structure
end

#checksum_algorithm ⇒ String

The algorithm used to generate the checksum. Currently, the only supported algorithm is SHA256.

Returns:

  • (String)


110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-ebs/types.rb', line 110

class CompleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :changed_blocks_count,
  :checksum,
  :checksum_algorithm,
  :checksum_aggregation_method)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_id ⇒ String

The ID of the snapshot.

Returns:

  • (String)


110
111
112
113
114
115
116
117
118
# File 'lib/aws-sdk-ebs/types.rb', line 110

class CompleteSnapshotRequest < Struct.new(
  :snapshot_id,
  :changed_blocks_count,
  :checksum,
  :checksum_algorithm,
  :checksum_aggregation_method)
  SENSITIVE = []
  include Aws::Structure
end