Class: Aws::EBS::Types::ListChangedBlocksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ebs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:changed_blocks]

Instance Attribute Summary collapse

Instance Attribute Details

#block_size ⇒ Integer

The size of the blocks in the snapshot, in bytes.

Returns:

  • (Integer)


326
327
328
329
330
331
332
333
334
# File 'lib/aws-sdk-ebs/types.rb', line 326

class ListChangedBlocksResponse < Struct.new(
  :changed_blocks,
  :expiry_time,
  :volume_size,
  :block_size,
  :next_token)
  SENSITIVE = [:changed_blocks]
  include Aws::Structure
end

#changed_blocks ⇒ Array<Types::ChangedBlock>

An array of objects containing information about the changed blocks.

Returns:



326
327
328
329
330
331
332
333
334
# File 'lib/aws-sdk-ebs/types.rb', line 326

class ListChangedBlocksResponse < Struct.new(
  :changed_blocks,
  :expiry_time,
  :volume_size,
  :block_size,
  :next_token)
  SENSITIVE = [:changed_blocks]
  include Aws::Structure
end

#expiry_time ⇒ Time

The time when the BlockToken expires.

Returns:

  • (Time)


326
327
328
329
330
331
332
333
334
# File 'lib/aws-sdk-ebs/types.rb', line 326

class ListChangedBlocksResponse < Struct.new(
  :changed_blocks,
  :expiry_time,
  :volume_size,
  :block_size,
  :next_token)
  SENSITIVE = [:changed_blocks]
  include Aws::Structure
end

#next_token ⇒ String

The token to use to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


326
327
328
329
330
331
332
333
334
# File 'lib/aws-sdk-ebs/types.rb', line 326

class ListChangedBlocksResponse < Struct.new(
  :changed_blocks,
  :expiry_time,
  :volume_size,
  :block_size,
  :next_token)
  SENSITIVE = [:changed_blocks]
  include Aws::Structure
end

#volume_size ⇒ Integer

The size of the volume in GB.

Returns:

  • (Integer)


326
327
328
329
330
331
332
333
334
# File 'lib/aws-sdk-ebs/types.rb', line 326

class ListChangedBlocksResponse < Struct.new(
  :changed_blocks,
  :expiry_time,
  :volume_size,
  :block_size,
  :next_token)
  SENSITIVE = [:changed_blocks]
  include Aws::Structure
end